@@ -67,14 +67,14 @@ def OxmlElement(nsptag_str, attrs=None, nsdecls=None):
 from .shared import CT_DecimalNumber, CT_OnOff, CT_String
 
 
-from .parts.coreprops import CT_CoreProperties
+from .coreprops import CT_CoreProperties
 register_element_cls('cp:coreProperties', CT_CoreProperties)
 
-from .parts.document import CT_Body, CT_Document
+from .document import CT_Body, CT_Document
 register_element_cls('w:body',     CT_Body)
 register_element_cls('w:document', CT_Document)
 
-from .parts.numbering import (
+from .numbering import (
     CT_Num, CT_Numbering, CT_NumLvl, CT_NumPr
 )
 register_element_cls('w:abstractNumId', CT_DecimalNumber)
