@@ -8,6 +8,7 @@ from __future__ import absolute_import, print_function, unicode_literals
 
 from ..enum.style import WD_STYLE_TYPE
 from ..enum.text import WD_BREAK
+from ..shape import InlineShape
 from ..shared import ElementProxy, Parented
 
 
@@ -57,23 +58,9 @@ class Run(Parented):
         (dpi) value specified in the image file, defaulting to 72 dpi if no
         value is specified, as is often the case.
         """
-        inline_shapes = self.part.inline_shapes
-        picture = inline_shapes.add_picture(image_path_or_stream, self)
-
-        # scale picture dimensions if width and/or height provided
-        if width is not None or height is not None:
-            native_width, native_height = picture.width, picture.height
-            if width is None:
-                scaling_factor = float(height) / float(native_height)
-                width = int(round(native_width * scaling_factor))
-            elif height is None:
-                scaling_factor = float(width) / float(native_width)
-                height = int(round(native_height * scaling_factor))
-            # set picture to scaled dimensions
-            picture.width = width
-            picture.height = height
-
-        return picture
+        inline = self.part.new_pic_inline(image_path_or_stream, width, height)
+        self._r.add_drawing(inline)
+        return InlineShape(inline)
 
     def add_tab(self):
         """
